@@ -2,6 +2,8 @@ package Lemonldap::NG::Common::Conf::Serializer;
 
 use Data::Dumper;
 
+our $VERSION = '1.1.0';
+
 BEGIN {
     *Lemonldap::NG::Common::Conf::normalize   = \&normalize;
     *Lemonldap::NG::Common::Conf::unnormalize = \&unnormalize;
@@ -107,12 +109,15 @@ sub unserialize {
 	|exportedHeaders
 	|exportedVars
 	|globalStorageOptions
+        |grantSessionRules
 	|groups
 	|locationRules
 	|logoutServices
 	|macros
 	|notificationStorageOptions
+	|persistentStorageOptions
 	|post
+        |reloadUrls
 	|remoteGlobalStorageOptions
 	|samlIDPMetaDataExportedAttributes
 	|samlIDPMetaDataOptions
@@ -121,6 +126,7 @@ sub unserialize {
 	|samlSPMetaDataOptions
 	|samlSPMetaDataXML
 	|samlStorageOptions
+        |sessionDataToRemember
 	|vhostOptions
 	)$/
             and $v ||= {} and not ref($v)
